import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()
    # remove header
    header_lines = 3
    long_description = long_description.split("\n", header_lines)[header_lines]

project_urls = {
    'Documentation': "https://github.com/bakobako/kcf_tools"
}

setuptools.setup(
    name="kcf.tools",
    version="0.0.4",
    author="Adam Bako",
    project_urls=project_urls,
    setup_requires=['pytest-runner'],
    tests_require=['pytest'],
    install_requires=[
        'Jinja2==3.1.1',
        'prompt_toolkit==1.0.14',
        'PyInquirer==1.0.3',
        'Pygments==2.11.2'
    ],
    author_email="adam.bako@keboola.com",
    description="Library with CLI tools to help in development of Keboola Python components",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/bakobako/kcf_tools",
    packages=['kcf.tools.readme_generator', 'kcf.tools.readme_generator.templates',
              'kcf.tools.help_doc_generator', 'kcf.tools.help_doc_generator.templates',
              'kcf.tools.config_schema_generator',
              'kcf.tools.generate_key_definitions',
              'kcf.tools.generate_client',
              'kcf.tools.help'
              ],
    package_data={'kcf.tools.readme_generator.templates': ['readme_template.md'],
                  'kcf.tools.help_doc_generator.templates': ['help_doc_template.md']},
    entry_points={'console_scripts':
                      ['generate_readme=kcf.tools.readme_generator.main:generate_readme',
                       'generate_help=kcf.tools.help_doc_generator.main:generate_help_doc',
                       'generate_config_schema=kcf.tools.config_schema_generator.main:generate_config_schema',
                       'generate_key_definitions=kcf.tools.generate_key_definitions.main:generate_key_definitions',
                       'generate_client=kcf.tools.generate_client.main:generate_client',
                       'kcf_help=kcf.tools.help.main:get_available_commands'
                       ]},
    include_package_data=True,
    zip_safe=False,
    test_suite='tests',
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Intended Audience :: Developers",
        "Intended Audience :: Information Technology",
        "Intended Audience :: Education",
        "Topic :: Software Development :: Libraries",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Development Status :: 5 - Production/Stable"
    ],
    python_requires='>=3.7'
)
